__version__ = '1.0.0'
__license__ = 'MIT'
__copyright__ = '(c) 2013-2014 Stefan Tatschner <stefan@sevenbyte.org>'
